#
# spec file for package pkcs11-provider
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2023 Luca Boccassi <bluca@debian.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _MODULES_DIR %(pkg-config --variable=modulesdir libcrypto)

Name:           pkcs11-provider
Version:        1.0
Release:        2.1
Summary:        A PKCS#11 provider for OpenSSL 3.0+
License:        Apache-2.0
Group:          Productivity/Security
URL:            https://github.com/latchset
Source0:        %{url}/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz
Source1:        %{url}/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libcrypto) >= 3.0.7
BuildRequires:  pkgconfig(p11-kit-1)
# Required for testing
BuildRequires:  expect
BuildRequires:  gnutls
BuildRequires:  opensc
BuildRequires:  p11-kit-devel
BuildRequires:  p11-kit-server
BuildRequires:  pkgconfig(nss)
%if 0%{?suse_version} >= 1699
BuildRequires:  softhsm-devel
%endif

%description
This is an Openssl 3.x provider to access Hardware or Software Tokens using
the PKCS#11 Cryptographic Token Interface.
This code targets version 3.0 of the cryptoki interface but should be backwards
compatible to previous versions as well.

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

%ifnarch s390x
%check
# do not run them in parrallel with %{?_smp_mflags}
%meson_test --num-processes 1
%endif

%files
%license COPYING
%doc README.md
%{_mandir}/man7/provider-pkcs11.*
%{_MODULES_DIR}/pkcs11.so

%changelog
* Tue Feb 25 2025 Lucas Mulling <lucas.mulling@suse.com>
- Don't run tests outside of Factory
* Thu Feb 13 2025 Lucas Mulling <lucas.mulling@suse.com>
- Update to 1.0:
  * Improved compatibility with PKCS#11 spec and historical module behavior in
    interpreting CKA_EC_POINT, thie handled incompatibilities in ECDSA/ECDH
    keys.
  * Added full RSA-PSS support
  * Fixed several issues with using keypairs after generation and loading of
    related public keys, espcially with the way OpenSSL handles ECDH peer key
    creation.
  * Fixed issues with EdDSA signatures
  * Expanded CI/testsuite with tlsfuzzer and more teting for Ed448 and other
    key types/operations
  * We test three different software tokens with 4 different test
    configurations
  * For a full list of changes see: https://github.com/latchset/pkcs11-provider/releases/tag/v1.0
- Remove patch explicit-EC-test-option.patch
* Tue Dec 17 2024 Lucas Mulling <lucas.mulling@suse.com>
- Update to 0.6:
  * TLS 1.3 is now supported via token handling (KDFs etc..)
  * A new feature to prevent PIN lockouts when the token correctly signals
    authentication attempts depletion via token info.
  * Several issues with handling keys related to run a full end-to-end TLS
    connection on the token have been fixed
  * Most cases when early loading was needed have been resolved, HTTP and Bind
    for example work without specifying early loading for the provider
  * Several memory leaks have been resolved
  * Several new tests including a whole new token (kryoptic) are tested now, as
    well as tlsfuzzer against a TLS server deferring all operations to the
    tokens.
  * For a full list of changes see: https://github.com/latchset/pkcs11-provider/releases/tag/v0.6
- Includes changes from 0.5 and 0.4
  * We moved the build system to Meson
  * A feature to embed pkcs11- URIs into "fake" PEM files has been added which
    makes it possible to transparently use the provider with many tools that
    accept keys only as PEM files.
  * For a full list of changes see:
    https://github.com/latchset/pkcs11-provider/releases/tag/v0.5
    https://github.com/latchset/pkcs11-provider/releases/tag/v0.4
- Add pkcs11-provider.keyring
- Enable unit testing for softokn and softhsm
- Add patch
  * explicit-EC-test-option.patch
* Fri Feb  9 2024 Luca Boccassi <bluca@debian.org>
- New upstream version version 0.3. For a full list of changes, see
  https://github.com/latchset/pkcs11-provider/releases/tag/v0.3
* Wed Oct 11 2023 Luca Boccassi <bluca@debian.org>
- Initial packaging of pkcs11-provider version 0.2
